==> zio-aws-amplifybackend_3-5.17.129.2-sources.jar: zio/aws/amplifybackend/model/CreateBackendAuthIdentityPoolConfig.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.{__boolean, __string}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class CreateBackendAuthIdentityPoolConfig(
    identityPoolName: __string,
    unauthenticatedLogin: __boolean
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.CreateBackendAuthIdentityPoolConfig = {
    import CreateBackendAuthIdentityPoolConfig.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.CreateBackendAuthIdentityPoolConfig
      .builder()
      .identityPoolName(__string.unwrap(identityPoolName): java.lang.String)
      .unauthenticatedLogin(
        __boolean.unwrap(unauthenticatedLogin): java.lang.Boolean
      )
      .build()
  }
  def asReadOnly
      : zio.aws.amplifybackend.model.CreateBackendAuthIdentityPoolConfig.ReadOnly =
    zio.aws.amplifybackend.model.CreateBackendAuthIdentityPoolConfig
      .wrap(buildAwsValue())
}
object CreateBackendAuthIdentityPoolConfig {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.CreateBackendAuthIdentityPoolConfig
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.amplifybackend.model.CreateBackendAuthIdentityPoolConfig =
      zio.aws.amplifybackend.model.CreateBackendAuthIdentityPoolConfig(
        identityPoolName,
        unauthenticatedLogin
      )
    def identityPoolName: __string
    def unauthenticatedLogin: __boolean
    def getIdentityPoolName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(identityPoolName)
    def getUnauthenticatedLogin: ZIO[Any, Nothing, __boolean] =
      ZIO.succeed(unauthenticatedLogin)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.CreateBackendAuthIdentityPoolConfig
  ) extends zio.aws.amplifybackend.model.CreateBackendAuthIdentityPoolConfig.ReadOnly {
    override val identityPoolName: __string =
      zio.aws.amplifybackend.model.primitives.__string(impl.identityPoolName())
    override val unauthenticatedLogin: __boolean =
      zio.aws.amplifybackend.model.primitives
        .__boolean(impl.unauthenticatedLogin())
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.CreateBackendAuthIdentityPoolConfig
  ): zio.aws.amplifybackend.model.CreateBackendAuthIdentityPoolConfig.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-amplifybackend_3-5.17.295.11-sources.jar: zio/aws/amplifybackend/model/CreateBackendAuthIdentityPoolConfig.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.{__boolean, __string}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class CreateBackendAuthIdentityPoolConfig(
    identityPoolName: __string,
    unauthenticatedLogin: __boolean
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.CreateBackendAuthIdentityPoolConfig = {
    import CreateBackendAuthIdentityPoolConfig.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.CreateBackendAuthIdentityPoolConfig
      .builder()
      .identityPoolName(identityPoolName: java.lang.String)
      .unauthenticatedLogin(unauthenticatedLogin: java.lang.Boolean)
      .build()
  }
  def asReadOnly
      : zio.aws.amplifybackend.model.CreateBackendAuthIdentityPoolConfig.ReadOnly =
    zio.aws.amplifybackend.model.CreateBackendAuthIdentityPoolConfig
      .wrap(buildAwsValue())
}
object CreateBackendAuthIdentityPoolConfig {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.CreateBackendAuthIdentityPoolConfig
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.amplifybackend.model.CreateBackendAuthIdentityPoolConfig =
      zio.aws.amplifybackend.model.CreateBackendAuthIdentityPoolConfig(
        identityPoolName,
        unauthenticatedLogin
      )
    def identityPoolName: __string
    def unauthenticatedLogin: __boolean
    def getIdentityPoolName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(identityPoolName)
    def getUnauthenticatedLogin: ZIO[Any, Nothing, __boolean] =
      ZIO.succeed(unauthenticatedLogin)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.CreateBackendAuthIdentityPoolConfig
  ) extends zio.aws.amplifybackend.model.CreateBackendAuthIdentityPoolConfig.ReadOnly {
    override val identityPoolName: __string = impl.identityPoolName(): __string
    override val unauthenticatedLogin: __boolean =
      impl.unauthenticatedLogin(): __boolean
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.CreateBackendAuthIdentityPoolConfig
  ): zio.aws.amplifybackend.model.CreateBackendAuthIdentityPoolConfig.ReadOnly =
    new Wrapper(impl)
}
